Improve this doc View Source

HTTP backend used by the service that delegates to XMLHttpRequest object or JSONP and deals with browser incompatibilities.

You should never need to use this service directly, instead use the higher-level abstractions: $http or $resource.

During testing this implementation is swapped with mock $httpBackend which can be trained with responses.

## Dependencies

- `$window`
- `$document`